@@ -1,7 +1,6 @@
 use log::*;
 use solana_sdk::{
-    instruction::InstructionError, keyed_account::KeyedAccount, process_instruction::InvokeContext,
-    pubkey::Pubkey,
+    instruction::InstructionError, process_instruction::InvokeContext, pubkey::Pubkey,
 };
 
 solana_sdk::declare_program!(
@@ -12,13 +11,11 @@ solana_sdk::declare_program!(
 
 pub fn process_instruction(
     program_id: &Pubkey,
-    keyed_accounts: &[KeyedAccount],
     data: &[u8],
     _invoke_context: &mut dyn InvokeContext,
 ) -> Result<(), InstructionError> {
     solana_logger::setup();
     trace!("noop: program_id: {:?}", program_id);
-    trace!("noop: keyed_accounts: {:#?}", keyed_accounts);
     trace!("noop: data: {:?}", data);
     Ok(())
 }
